Survival analysis
epoc.svd(model, k=1, C=1, numload=NULL)
epoc.survival(G.svd, Y, U, surv, C=1, type=NULL)
epoc.svdplot(G.svd, C=1)
# S3 method for EPoC.survival
plot(x,...)
# S3 method for EPoC.survival
summary(object,...)
# S3 method for summary.EPoC.survival
print(x,...)An object from epocG or epocA or a Matrix from epoc.bootstrap and friends.
In case model come from epocG or epocA select a model of sparsity level k in [1,K]. The default k=1 means first/most sparse.
Default 1. For epoc.svd the number of components. For epoc.survival and epoc.svdplot, which component to use.
Number of loadings in the sparse components, a vector for each component. Default 10 for all components.
The list obtained from epoc.svd.
mRNA, samples x genes.
CNA, samples x genes.
Survival data for the samples.
'G' means EPoC G and 'A' means EPoC A.
An object from epoc.survival
An object from epoc.survival
Parameters passed down to underlying functions, plot.default for plot and print.default for print.
The epoc.survival object contains the summary information from a log-rank test comparing survival (survdiff) and survival fit objects.
Applies survival analysis using the first SVD component, but other components can also be used by changing the input value of C. Survival scores are generated as described in Subsect. 2.4 in the second paper referenced. A simple non-parametric survival analysis is performed, comparing survival between patientswith positive or negative scores (tumor fitness).
Rebecka J<U+00F6>rnsten, Tobias Abenius, Teresia Kling, Linn<U+00E9>a Schmidt, Erik Johansson, Torbj<U+00F6>rn Nordling, Bodil Nordlander, Chris Sander, Peter Gennemark, Keiko Funa, Bj<U+00F6>rn Nilsson, Linda Lindahl, Sven Nelander. (2011) Network modeling of the transcriptional effects of copy number aberrations in glioblastoma. Molecular Systems Biology 7
Tobias Abenius, Rebecka J<U+00F6>rnsten, Teresia Kling, Linn<U+00E9>a Schmidt, Jos<U+00E9> S<U+00E1>nchez, Sven Nelander. (2012) System-scale network modeling of cancer using EPoC. Advances in experimental medicine and biology
epoc, epoc.validation and spca