Model validation using random split or cross-validation
epoc.validation(type=c('pred','concordance'),repl,Y,U,lambdas=NULL,
method='G',thr=1e-10,trace=0,...)'pred' for 10-fold CV of prediction error. 'concordance' for random split network concordance using Kendall \(W\).
The number of replicates
mRNA, samples x genes
CNA, samples x genes
series of relative \(\lambda\)s or default=NULL which means let EPoC choose
'G' means EPoC G and 'A' means EPoC A.
Threshold for convergence to the LASSO solver
Debug information
Extra parameters passed through to the EPoC solver
A list of class plot.EPoC.validation.pred or plot.EPoC.validation.W respectively.
In the case of 'pred' assess CV prediction error using 10-fold cross-validation with repl replicates.
In the case of 'concordance' assess network concordance using random split and Kendall W with repl replicates.
Rebecka J<U+00F6>rnsten, Tobias Abenius, Teresia Kling, Linn<U+00E9>a Schmidt, Erik Johansson, Torbj<U+00F6>rn Nordling, Bodil Nordlander, Chris Sander, Peter Gennemark, Keiko Funa, Bj<U+00F6>rn Nilsson, Linda Lindahl, Sven Nelander. (2011) Network modeling of the transcriptional effects of copy number aberrations in glioblastoma. Molecular Systems Biology 7 (to appear)